@@ -23,6 +23,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.file.Files;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
@@ -34,6 +35,7 @@ import java.util.zip.ZipOutputStream;
 import static net.lingala.zip4j.testutils.TestUtils.getTestFileFromResources;
 import static net.lingala.zip4j.testutils.ZipFileVerifier.verifyFileContent;
 import static net.lingala.zip4j.util.InternalZipConstants.MIN_BUFF_SIZE;
+import static net.lingala.zip4j.util.InternalZipConstants.USE_UTF8_FOR_PASSWORD_ENCODING_DECODING;
 import static org.assertj.core.api.Assertions.assertThat;
 
 public class ZipInputStreamIT extends AbstractIT {
@@ -44,7 +46,7 @@ public class ZipInputStreamIT extends AbstractIT {
   @Test
   public void testZipInputStreamConstructorThrowsExceptionWhenBufferSizeIsLessThanExpected() {
     InputStream inputStream = new ByteArrayInputStream(new byte[1]);
-    Zip4jConfig zip4jConfig = new Zip4jConfig(null, InternalZipConstants.MIN_BUFF_SIZE - 1);
+    Zip4jConfig zip4jConfig = new Zip4jConfig(null, InternalZipConstants.MIN_BUFF_SIZE - 1, USE_UTF8_FOR_PASSWORD_ENCODING_DECODING);
 
     expectedException.expect(IllegalArgumentException.class);
     expectedException.expectMessage("Buffer size cannot be less than " + MIN_BUFF_SIZE + " bytes");
@@ -337,6 +339,18 @@ public class ZipInputStreamIT extends AbstractIT {
         null, InternalZipConstants.BUFF_SIZE, false, 1);
   }
 
+  @Test
+  public void readingJarFileWithCompressedSizeNotZeroForDirectoryIsSuccessful() throws IOException {
+    File zipFileToRead = getTestArchiveFromResources("content_in_entry_which_is_directory.jar");
+    try (ZipInputStream zipInputStream = new ZipInputStream(Files.newInputStream(zipFileToRead.toPath()))) {
+      int numberOfEntries = 0;
+      while (zipInputStream.getNextEntry() != null) {
+        numberOfEntries++;
+      }
+      assertThat(numberOfEntries).isEqualTo(345);
+    }
+  }
+
   private void extractZipFileWithInputStreams(File zipFile, char[] password) throws IOException {
     extractZipFileWithInputStreams(zipFile, password, InternalZipConstants.BUFF_SIZE);
   }
